**************************
* Regression code for Beer data
* This code can be use to obtain the estimates in the paper when accompanied with the true/confidential data
* and can also be used to recover estimates from the simulated data
**************************



**************************
* Note on Running Code on Simulated Data Set
**************************
* The simulated data was created based on two unique models with the most general specifications:
*   Table 2(6) and Table 8(4)
*      Preceding columns of these tables involve turning off some variables of these two more general models
*         I have not generated the simulated data to be robust to turning off these other variables so
*         columns 1 to 5 in Tbl2 and 1 to 3 in Tbl8 may not be replicated from the simulated data
*      Table 6 is also a sub-model of Table 8 in that it turns off the NCAA variables. 
*         Similarly we have not generated the data so that effects show up when turning off the NCAA tournament
*         eventhough that does occur in the real data
*      Figure 4 is technically more general than Tbl 8 in that coefficients vary by week, but is less general in that it excludes NCAA viewership data
*         We choose not to generate data based on that because of the complexity
* In summary, while a simulated data set is good to prove out a model, it may
* not be a great fit for a descriptive paper intended to recover patterns in data
* It is an odd, and onerous task, to replicate the many rich patterns the analysis in the paper was
* intended to uncover.
**************************


use BeerDataForRegs

*The commands below should be uncommented when running on simulated data
*insheet using BeerForRegs.txt
*rename v1 beerbnum
*rename v2 dma
*rename v3 year
*rename v4 superweek
*rename v5 v72HH
*rename v6 RevHH
*rename v7 rtg
*rename v8 rtg_ad
*rename v9 rtgNCAA
*rename v10 NCAArtg
*rename v11 NCAArtg_ad
*rename v12 NCAAbud
*rename v13 price
*rename v14 priceother
*rename v15 PostGRPs
*rename v16 NFLgrps
*rename v17 display
*rename v18 feature
*rename v19 top56
*rename v20 beeryear
*rename v21 branddma
*drop v22


*************************
* Correct Ratings Dilution in Markets 57-210
*************************
	*Next line explians the ratings measurement in non-top 56 markets (via email on 9/9/2013)
		*"the ratings that are applied are diary ratings because markets outside #56 are not metered; they are measured via diary. The diary ratings used are 4 week quarter hour average, so it is not the Super Bowl that is exactly being measured but its airing averaged with all Sunday activity in February"
	*We treat the data generating process for these ratings as 
		*Rdiluted = (SBratings + Wk2ratings + Wk3ratings + Wk4ratings)/4
		*Rdiluted = SBratings/4  + (Wk2ratings + Wk3ratings + Wk4ratings)/4
		*Rdiluted = SBratings/4  + errror/4
		*SBratings= 4*Rdiluted - error
		
		*error is not however mean zero which could create problems when combining with undiluted ratings in the top 56 markets in the same regression.
			* In other words, running top56 and 57+ markets together requires normalizing so the error is zero
		*We do however know the mean ratings based on what we observe in the top 56,
		*so we calculate that by year and use it to shift imputed ratings
			*Calculate average ratings by top 56 and year
				egen aRtg56_210 = mean(rtg),by(top56 year)
			*Calculate average ratings by year for just the top 56 (should be higher because not diluted)
				egen aRtg56 = max(aRtg56_210),by(year)
			*Next, we'll calculate the common difference/shift for top 56 markets vs. the 210 markets ratings multiplied by 4
				gen mZ = (aRtg56_210 * 4) - aRtg56
				*Now we apply the shift to 4*Rdiluted
				gen rtgAdj = 4*rtg -mZ 
					* Note that is calculated for all markets but will only "replace" ratings for the 57+ markets

	*Next, we develop the measurement error correction for the 57+ markets
		*We can calculate the amount of error (and hence bias) for the 57+ markets because we know the variance of ratings within top 56 relative to the 210 which has the error from above
			*Calculate the std dev of ratings by top56 and year
			*Define variables for the std of Rtgs for top 56 to pull out top 56 sd of ratings
				egen sdRtg56_210 = sd(rtg),by(top56 year)
				gen sdRtg56a = sdRtg56_210 * (top56==1)
				egen sdRtg56 = max(sdRtg56a),by(year)
			* Now we can calculate std of Rtgs for the mean adjusted ratings above (rtgAdj)		
				egen sdRtgAdja = sd(rtgAdj),by(top56 year)
				replace sdRtgAdja = 0 if top56==1
				egen sdRtgAdj = max(sdRtgAdja),by(year)
		*Because the data with error is jointly analyze with data without error, we cannot do ex-post correction for the measurement error
		*Rather, we can correct it by rescaling the underlying data in the errored markets by lambda as follows: 
			*The scaling 57+ markets is the true variance (from top56) divided by the variance of the errored ratings measure (from rtgAdj)
				gen lambda = (sdRtg56^2 ) /(sdRtgAdj^2 )
				gen rtg_old = rtg
				replace rtg = rtgAdj*lambda if top56==0
				replace rtg_ad = rtg * (rtg_ad>0)
		*Notes from simulation exercise/recovery work run after paper acceptance
			*This approach is validated by the recovery of the estimates after simulating the dilution problem
			*While we did correct for the mean differences to combine the data into the same regressions, some differences remain because of the lambda scaling only applied to the 57+ markets
				*This could affect results because some other variables may be correlated with being a 57+ market, or for example, a year fixed effect could be different if held constant across the top 56 and 57+ markets
				*This was not a problem in the observed data but did arise in some simulations.  When it arises in simulations, other variables can be interacted with an indicator for top56 so that it is like running the two regressions separate in all other ways
					*We tried including such interactions on the real data and they did not alter the focal coefficients, but did reduce precision
					*In some simulations, these interactions mattered more when rtg_ad was interacted with NCAA ratings.  We think this is because NCAA ratings has error as well but we do not know the exact form to correct it.  Hence, we sometimes see attenuation in the NCAArtg_ad coefficient in simulations.  Once again, we do not see these interactions affecting the NCAArtg_ad coefficent for the real data
				
				
				
				


***********************
* Missing from accepted version ... never re-corrected the interactions with NCAA after correcting the rtg variable in 57+ markets
***********************
	replace NCAArtg = rtgNCAA*rtg
	replace NCAArtg_ad = rtgNCAA*rtg_ad
	



*****************
* Create Data Labels for Output
*****************
	label var rtg "Ratings"
	label var rtg_ad "Ratings * Ad"
	label var PostGRPs "GRPs"
	label var NFLgrps "NFL GRPs" 
	label var price "Price"
	label var priceother "Price * Other"
	label var feature "Feature"
	label var display "Display"
	
	label var NCAArtg "NCAA * Ratings"
	label var NCAArtg_ad "NCAA * Ratings * Ad"
	label var NCAAbud "NCAA * Bud"
	label var rtgNCAA "NCAA"



*****************
* Begin Regressions
*****************
	local window = 8
	local top56 = 210

******************
** Create Figure 3 and 4 (weekly regressions)
******************
	forvalues wknum = 1 (1)20 {
	 xi: xtreg   RevHH rtg_ad rtg   i.beeryear if superweek==`wknum' , fe i(branddma) cluster(dma)
	        outreg2 rtg_ad          using RevBeerByWk`top56'.txt, ti(Summary Regressions of Superbowl Ratings) ctitle(Weeks `wknum' ) label  nocon  dec(3) 2aster keep(rtg_ad)
	 xi: xtreg   v72HH rtg_ad rtg   i.beeryear if superweek==`wknum' , fe i(branddma) cluster(dma)
	        outreg2 rtg_ad          using v72BeerByWk`top56'.txt, ti(Summary Regressions of Superbowl Ratings) ctitle(Weeks `wknum' ) label  nocon  dec(3) 2aster keep(rtg_ad)
	}




*****************
* Create Table 2
*****************
	preserve
	keep if superweek==0
		xi: xtreg   v72HH rtg                                              i.beeryear if beerbnum==1 , fe i(branddma) cluster(dma)
	     outreg2                                                      using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud )   nocon  dec(3) 2aster       keep(rtg) replace label
		xi: xtreg   v72HH rtg     PostGRPs NFLgrps price feature display   i.beeryear if beerbnum==1 , fe i(branddma) cluster(dma)
	     outreg2        rtg     PostGRPs NFLgrps price feature display   using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud )   nocon  dec(3) 2aster               keep(rtg PostGRPs NFLgrps price feature display) label
		xi: xtreg   v72HH        rtg                                          i.beeryear if beerbnum~=1 , fe i(branddma) cluster(dma)
	     outreg2               rtg                                          using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster        keep( rtg ) label
		xi: xtreg   v72HH        rtg PostGRPs NFLgrps price priceother feature display   i.beeryear if beerbnum~=1 , fe i(branddma) cluster(dma)
	     outreg2               rtg PostGRPs NFLgrps price priceother feature display   using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster        keep(rtg PostGRPs NFLgrps price priceother feature display) label
		xi: xtreg   v72HH rtg rtg_ad                                          i.beeryear, fe i(branddma) cluster(dma)
	     outreg2        rtg rtg_ad                                          using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All )   nocon  dec(3) 2aster            keep(rtg rtg_ad ) label
		xi: xtreg   v72HH rtg rtg_ad PostGRPs NFLgrps price priceother feature display   i.beeryear, fe i(branddma) cluster(dma)                                                                                            
	       outreg2      rtg rtg_ad PostGRPs NFLgrps price priceother feature display   using Post`top56'Wk0BeerRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All )   nocon  dec(3) 2aster keep(rtg rtg_ad PostGRPs NFLgrps price priceother feature display) label
	restore


*****************
* Create Tables 4 & 5
*****************
	preserve
	drop if superweek>`window'
		*Table 4(1)
			xi: xtreg   v72HH rtg_ad  i.superweek          i.beeryear  if beerbnum==1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad            using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud Only )   nocon  dec(3) 2aster replace keep(rtg_ad ) label
		*Table 4(2)
			xi: xtreg   v72HH rtg_ad  i.superweek          PostGRPs NFLgrps price priceother feature display   i.beeryear if beerbnum==1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad            PostGRPs NFLgrps price priceother feature display   using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud Only )   nocon  dec(3) 2aster keep(rtg_ad            PostGRPs NFLgrps price priceother feature display) label

		*Table 5(1)
			xi: xtreg   RevHH rtg_ad  i.superweek          i.beeryear  if beerbnum==1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad            using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud Only)   nocon  dec(3) 2aster replace keep(rtg_ad ) label
		*Table 5(2)
			xi: xtreg   RevHH rtg_ad  i.superweek         PostGRPs NFLgrps price priceother feature display   i.beeryear if beerbnum==1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad            PostGRPs NFLgrps price priceother feature display   using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Bud Only )   nocon  dec(3) 2aster keep(rtg_ad            PostGRPs NFLgrps price priceother feature display ) label
	
	restore
	
	preserve
	drop if superweek>`window'
		*Table 4(3)
			xi: xtreg   v72HH             rtg   i.superweek i.beeryear   if beerbnum~=1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2                    rtg   using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster keep(rtg) label
		*Table 4(4)
			xi: xtreg   v72HH             rtg   PostGRPs NFLgrps price priceother feature display i.beeryear  i.superweek if beerbnum~=1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2                    rtg   PostGRPs NFLgrps price priceother feature display using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster keep(rtg   PostGRPs NFLgrps price priceother feature display) label
		*Table 4(5)
			xi: xtreg   v72HH rtg_ad rtg   i.superweek i.beeryear   if superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad rtg   using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands )   nocon  dec(3) 2aster keep(rtg_ad rtg) label
		*Table 4(6)
			xi: xtreg   v72HH rtg_ad rtg   PostGRPs NFLgrps price priceother feature display  i.superweek  i.beeryear if superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad rtg   PostGRPs NFLgrps price priceother feature display   using Post`top56'BeerRegsVol`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands )   nocon  dec(3) 2aster keep(rtg_ad rtg   PostGRPs NFLgrps price priceother feature display) label

		*Table 5(3)
			xi: xtreg   RevHH             rtg   i.superweek i.beeryear  if beerbnum~=1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2                    rtg   using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster keep(rtg) label
		*Table 5(4)
			xi: xtreg   RevHH             rtg   PostGRPs NFLgrps price priceother feature display  i.superweek i.beeryear  if beerbnum~=1 & superweek>0, fe i(branddma) cluster(dma)
	       outreg2                    rtg   PostGRPs NFLgrps price priceother feature display using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Non-Bud )   nocon  dec(3) 2aster keep(rtg   PostGRPs NFLgrps price priceother feature display) label
		*Table 5(5)
			xi: xtreg   RevHH rtg_ad rtg   i.superweek i.beeryear  i.superweek if superweek>0, fe i(branddma) cluster(dma)
	       outreg2        rtg_ad rtg   using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands )   nocon  dec(3) 2aster keep(rtg_ad rtg) label
		*Table 5(6)
			xi: xtreg   RevHH rtg_ad rtg   PostGRPs NFLgrps price priceother feature display   i.superweek i.beeryear if superweek>0, fe i(branddma) cluster(dma) 
	       outreg2        rtg_ad rtg   PostGRPs NFLgrps price priceother feature display   using Post`top56'BeerRegs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands )   nocon  dec(3) 2aster keep(rtg_ad rtg PostGRPs NFLgrps price priceother feature display) label
	restore


*****************
* Create Beer Portion of Tables 8 and 9
*****************
	keep if superweek<=20
	preserve
	keep if superweek>0
		*Table 8
			xi: xtreg   v72HH  rtg_ad rtg   i.superweek i.beeryear , fe i(branddma) cluster(dma)
	       outreg2         using NCAAvol`top56'Regs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Beer)   nocon  dec(3) 2aster tex keep(rtg_ad rtg ) replace label
			xi: xtreg   v72HH  rtg_ad rtg PostGRPs NFLgrps price priceother feature display   i.superweek i.beeryear , fe i(branddma) cluster(dma)
	       outreg2         rtg_ad rtg PostGRPs NFLgrps price priceother feature display   using NCAAvol`top56'Regs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Beer)   nocon  dec(3) 2aster tex keep(rtg_ad rtg NCAA* rtgNCAA PostGRPs NFLgrps price priceother feature display)  label
			xi: xtreg   v72HH  rtg_ad rtg NCAA* rtgNCAA   i.superweek  i.beeryear , fe i(branddma) cluster(dma)
	       outreg2         using NCAAvol`top56'Regs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Beer)   nocon  dec(3) 2aster tex keep(rtg_ad rtg NCAArtg NCAArtg_ad NCAAbud rtgNCAA) label
			xi: xtreg   v72HH  rtg_ad rtg NCAA* rtgNCAA PostGRPs NFLgrps price priceother feature display   i.superweek i.beeryear , fe i(branddma) cluster(dma)
	       outreg2           using NCAAvol`top56'Regs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Beer)   nocon  dec(3) 2aster tex keep(rtg_ad rtg NCAArtg NCAArtg_ad NCAAbud rtgNCAA PostGRPs NFLgrps price priceother feature display) label
		*Table 9
			xi: xtreg   RevHH  rtg_ad rtg   i.superweek i.beeryear , fe i(branddma) cluster(dma)
	       outreg2         rtg_ad rtg   using NCAA`top56'Regs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Beer)   nocon  dec(3) 2aster tex keep(rtg_ad rtg NCAA* rtgNCAA PostGRPs NFLgrps price priceother feature display) replace label
			xi: xtreg   RevHH  rtg_ad rtg PostGRPs NFLgrps price priceother feature display  i.superweek  i.beeryear , fe i(branddma) cluster(dma)
	       outreg2         rtg_ad rtg PostGRPs NFLgrps price priceother feature display   using NCAA`top56'Regs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Beer)   nocon  dec(3) 2aster tex keep(rtg_ad rtg NCAA* rtgNCAA PostGRPs NFLgrps price priceother feature display)  label
			xi: xtreg   RevHH  rtg_ad rtg NCAA* rtgNCAA   i.superweek  i.beeryear , fe i(branddma) cluster(dma)
	       outreg2         rtg_ad rtg NCAA* rtgNCAA    using NCAA`top56'Regs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Beer)   nocon  dec(3) 2aster tex keep(rtg_ad rtg NCAA* rtgNCAA PostGRPs NFLgrps price priceother feature display) label
			xi: xtreg   RevHH  rtg_ad rtg NCAA* rtgNCAA PostGRPs NFLgrps price priceother feature display   i.superweek i.beeryear , fe i(branddma) cluster(dma)
	       outreg2         rtg_ad rtg NCAA* rtgNCAA PostGRPs NFLgrps price priceother feature display   using NCAA`top56'Regs`window'.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Beer)   nocon  dec(3) 2aster tex keep(rtg_ad rtg NCAA* rtgNCAA PostGRPs NFLgrps price priceother feature display) label
	restore
			