**************************
* Regression code for Soda data
* This code can be use to obtain the estimates in the paper when accompanied with the true/confidential data
* and can also be used to recover estimates from the simulated data
**************************



**************************
* Note on Running Code on Simulated Data Set
**************************
* The simulated data was created based on two unique models with the most general specifications:
*   Table 3(6) and Table 8(8)
*      Preceding columns of these tables involve turning off some variables of these two more general models
*         I have not generated the simulated data to be robust to turning off these other variables so
*         columns 1 to 5 in Tbl2 and 5 to 7 in Tbl8 are not replicated in the simulated data.
*         One factor here is that the simulation specification currently leads to an Rsq near 1 (vs. 0.299 in paper), which drops to less than 0.001 when covariates are dropped  
*      Table 7 is also a sub-model of Table 8 in that it turns off the NCAA variables. 
*         Similarly we have not generated the data so that effects show up when turning off the NCAA tournament
*         eventhough that does occur in the real data
*      Figure 5 is technically more general than Tbl 8 in that coefficients vary by week, but is less general in that it excludes NCAA viewership data
*         We choose not to generate data based on that because of the complexity
* In summary, while a simulated data set is good to prove out a model, it may
* not be a great fit for a descriptive paper intended to recover patterns in data
* It is an odd, and onerous task, to replicate the many rich patterns the analysis in the paper was
* intended to uncover.
**************************


use SodaDataForRegs
drop NCAACoke
set more off
*The commands below should be uncommented when running on simulated data
*insheet using SodaForRegs.txt
*rename v1  brandnum       
*rename v2  dma            
*rename v3  year           
*rename v4  superweek      
*rename v5  v72HH           
*rename v6  RevHH          
*rename v7  rtg            
*rename v8  rtg_ad         
*rename v9  rtg_ad_both    
*rename v10 rtgPepsi        
*rename v11 rtgCoke         
*rename v12 rtg_adPepsi     
*rename v13 rtg_adCoke      
*rename v14 rtgNCAA         
*rename v15 NCAArtg         
*rename v16 NCAArtg_ad      
*rename v17 NCAArtg_ad_both 
*rename v18 NCAAPepsi       
*rename v19 price           
*rename v20 priceother      
*rename v21 PostGRPs        
*rename v22 NFLgrps        
*rename v23 display        
*rename v24 feature        
*rename v25 top56          
*rename v26 sodayear       
*rename v27 branddma       
*rename v28 sodabnum
*drop v29
*drop rtgCoke rtgPepsi rtg_adCoke rtg_adPepsi
*	*The above is redefined later in the code  ... but not there to drop in non-simulated data


*************************
* Correct Ratings Dilution in Markets 57-210
*************************
	*Next line explians the ratings measurement in non-top 56 markets (via email on 9/9/2013)
		*"the ratings that are applied are diary ratings because markets outside #56 are not metered; they are measured via diary. The diary ratings used are 4 week quarter hour average, so it is not the Super Bowl that is exactly being measured but its airing averaged with all Sunday activity in February"
	*We treat the data generating process for these ratings as 
		*Rdiluted = (SBratings + Wk2ratings + Wk3ratings + Wk4ratings)/4
		*Rdiluted = SBratings/4  + (Wk2ratings + Wk3ratings + Wk4ratings)/4
		*Rdiluted = SBratings/4  + errror/4
		*SBratings= 4*Rdiluted - error
		
		*error is not however mean zero which could create problems when combining with undiluted ratings in the top 56 markets in the same regression.
			* In other words, running top56 and 57+ markets together requires normalizing so the error is zero
		*We do however know the mean ratings based on what we observe in the top 56,
		*so we calculate that by year and use it to shift imputed ratings
			*Calculate average ratings by top 56 and year
				egen aRtg56_210 = mean(rtg),by(top56 year)
			*Calculate average ratings by year for just the top 56 (should be higher because not diluted)
				egen aRtg56 = max(aRtg56_210),by(year)
			*Next, we'll calculate the common difference/shift for top 56 markets vs. the 210 markets ratings multiplied by 4
				gen mZ = (aRtg56_210 * 4) - aRtg56
				*Now we apply the shift to 4*Rdiluted
				gen rtgAdj = 4*rtg -mZ 
					* Note that is calculated for all markets but will only "replace" ratings for the 57+ markets

	*Next, we develop the measurement error correction for the 57+ markets
		*We can calculate the amount of error (and hence bias) for the 57+ markets because we know the variance of ratings within top 56 relative to the 210 which has the error from above
			*Calculate the std dev of ratings by top56 and year
			*Define variables for the std of Rtgs for top 56 to pull out top 56 sd of ratings
				egen sdRtg56_210 = sd(rtg),by(top56 year)
				gen sdRtg56a = sdRtg56_210 * (top56==1)
				egen sdRtg56 = max(sdRtg56a),by(year)
			* Now we can calculate std of Rtgs for the mean adjusted ratings above (rtgAdj)		
				egen sdRtgAdja = sd(rtgAdj),by(top56 year)
				replace sdRtgAdja = 0 if top56==1
				egen sdRtgAdj = max(sdRtgAdja),by(year)
		*Because the data with error is jointly analyze with data without error, we cannot do ex-post correction for the measurement error
		*Rather, we can correct it by rescaling the underlying data in the errored markets by lambda as follows: 
			*The scaling 57+ markets is the true variance (from top56) divided by the variance of the errored ratings measure (from rtgAdj)
				gen lambda = (sdRtg56^2 ) /(sdRtgAdj^2 )
				gen rtg_old = rtg
				replace rtg = rtgAdj*lambda if top56==0
				replace rtg_ad = rtg * (rtg_ad>0)
				replace rtg_ad_both = rtg * (rtg_ad_both>0)
		*Notes from simulation exercise/recovery work run after paper acceptance
			*This approach is validated by the recovery of the estimates after simulating the dilution problem
			*While we did correct for the mean differences to combine the data into the same regressions, some differences remain because of the lambda scaling only applied to the 57+ markets
				*This could affect results because some other variables may be correlated with being a 57+ market, or for example, a year fixed effect could be different if held constant across the top 56 and 57+ markets
				*This was not a problem in the observed data but did arise in some simulations.  When it arises in simulations, other variables can be interacted with an indicator for top56 so that it is like running the two regressions separate in all other ways
					*We tried including such interactions on the real data and they did not alter the focal coefficients, but did reduce precision
					*In some simulations, these interactions mattered more when rtg_ad was interacted with NCAA ratings.  We think this is because NCAA ratings has error as well but we do not know the exact form to correct it.  Hence, we sometimes see attenuation in the NCAArtg_ad coefficient in simulations.  Once again, we do not see these interactions affecting the NCAArtg_ad coefficent for the real data

***********************
* Missing from accepted version ... never re-corrected the interactions with NCAA after correcting the rtg variable in 57+ markets
***********************
	replace NCAArtg = rtgNCAA*rtg
	replace NCAArtg_ad = rtgNCAA*rtg_ad
	replace NCAArtg_ad_both = rtgNCAA*rtg_ad_both
	
***********************
* Additional ratings interactions to show Coke and Pepsi movement w/ SB viewership separately from each other ... whether advertising or not 
*  Needed for Table 3 which was added during revisions
***********************
	gen rtgCoke=rtg*(sodabnum==1)
	gen rtgPepsi=rtg*(sodabnum==5)
	gen rtg_adCoke=rtg_ad*(sodabnum==1)
	gen rtg_adPepsi=rtg_ad*(sodabnum==5)
	

*****************
* Create Data Labels for Output
*****************
	label var rtg "Ratings"
	label var rtg_ad "Ratings * Ad"
	label var rtg_ad_both "Ratings * Ad*Ad"
	label var PostGRPs "GRPs"
	label var NFLgrps "NFL GRPs" 
	label var price "Price"
	label var priceother "Price * Other"
	label var feature "Feature"
	label var display "Display"

	label var NCAArtg "NCAA * Ratings"
	label var NCAArtg_ad "NCAA * Ratings * Ad"
	label var NCAArtg_ad_both "NCAA * Ratings * Ad*Ad"
	label var NCAAPepsi "NCAA * Pepsi"
	label var rtgNCAA "NCAA"

	label var rtg_adCoke "Ratings * Ad * Coke"
	label var rtgCoke "Ratings * Coke"
	label var rtg_adPepsi "Ratings * Ad * Pepsi"
	label var rtgPepsi "Ratings * Pepsi"


*****************
* Begin Regressions
*****************
	local top56 = 210


preserve
keep if superweek==0
	xi: xtreg   v72HH rtg_adCoke rtgCoke                                          i.sodayear if sodabnum==1 , fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Dependent Variable: Volume per Household) ctitle(Coke )   nocon  dec(3) 2aster replace keep(rtg_adCoke rtgCoke) label
	xi: xtreg   v72HH rtg_adPepsi rtgPepsi                                          i.sodayear if sodabnum==5 , fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Pepsi )   nocon  dec(3) 2aster  keep(rtg_adPepsi rtgPepsi) label
	xi: xtreg   v72HH rtg_adCoke rtgCoke PostGRPs NFLgrps price feature display   i.sodayear if sodabnum==1 , fe i(branddma) cluster(dma)
     outreg2                                                             using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Coke )   nocon  dec(3) 2aster keep(rtg_adCoke rtgCoke PostGRPs NFLgrps price feature display) label
	xi: xtreg   v72HH rtg_adPepsi rtgPepsi PostGRPs NFLgrps price feature display   i.sodayear if sodabnum==5 , fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Pepsi )   nocon  dec(3) 2aster keep(rtg_adPepsi rtgPeps PostGRPs NFLgrps price feature display) label
	xi: xtreg   v72HH rtg_ad rtg                                          i.sodayear if sodabnum~=1 & sodabnum~=5 , fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Not CokePepsi )   nocon  dec(3) 2aster keep( rtg_ad rtg ) label
	xi: xtreg   v72HH rtg_ad rtg PostGRPs NFLgrps price priceother feature display   i.sodayear if sodabnum~=1 & sodabnum~=5 , fe i(branddma) cluster(dma)
     outreg2                                                             using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(Not CokePepsi )   nocon  dec(3) 2aster keep(rtg_ad rtg PostGRPs NFLgrps price priceother feature display) label
	xi: xtreg   v72HH rtg_adCoke rtgCoke rtg_adPepsi rtgPepsi rtg                                          i.sodayear, fe i(branddma) cluster(dma)
     outreg2                                                            using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All )   nocon  dec(3) 2aster keep(rtg_adCoke rtgCoke rtg_adPepsi rtgPepsi rtg ) label
	xi: xtreg   v72HH rtg_adCoke rtgCoke rtg_adPepsi rtgPepsi rtg_ad rtg PostGRPs NFLgrps price priceother feature display   i.sodayear, fe i(branddma) cluster(dma)
       outreg2                                                          using Post`top56'Wk0SodaRegs.tex, ti(Summary Regressions of Superbowl Ratings) ctitle(All )   nocon  dec(3) 2aster keep(rtg_adCoke rtgCoke rtg_adPepsi rtgPepsi rtg PostGRPs NFLgrps price priceother feature display) label
restore

  stop

forvalues wknum = 1 (1)20 {
   xi:xtreg   RevHH rtg_ad rtg_ad_both rtg i.sodayear if superweek==`wknum' & ( (brandnum==5)+(brandnum==1)==1), fe i(branddma) cluster(dma)
         outreg2 rtg_ad_both rtg_ad rtg  using RevCokePepsiByWk`top56'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Weeks `wknum' ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg)
   xi:xtreg   v72HH rtg_ad rtg_ad_both rtg i.sodayear if superweek==`wknum' & ( (brandnum==5)+(brandnum==1)==1), fe i(branddma) cluster(dma)
         outreg2 rtg_ad_both rtg_ad rtg  using VolCokePepsiByWk`top56'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Weeks `wknum' ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg)
}

local window = 8

preserve
drop if superweek>`window'

		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg i.superweek   i.sodayear           if (sodabnum==1 | sodabnum==5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg    using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg) replace
		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg i.superweek PostGRPs NFLgrps price  feature display   i.sodayear           if (sodabnum==1 | sodabnum==5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price  feature display   using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price  feature display )
		xi: xtreg   RevHH rtg_ad                  rtg i.superweek   i.sodayear           if (sodabnum~=1 & sodabnum~=5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad                  rtg    using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Not Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad                  rtg)
		xi: xtreg   RevHH rtg_ad                  rtg i.superweek PostGRPs NFLgrps price priceother feature display   i.sodayear           if (sodabnum~=1 & sodabnum~=5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad                  rtg  PostGRPs NFLgrps price priceother feature display   using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Not Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad                  rtg  PostGRPs NFLgrps price priceother feature display)
		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg i.superweek                                           i.sodayear           if  superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg                                            using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg )
		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg i.superweek PostGRPs NFLgrps price priceother feature display   i.sodayear           if  superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price priceother feature display   using Post`top56'SodaRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price priceother feature display)

		xi: xtreg   v72HH rtg_ad rtg_ad_both rtg i.superweek   i.sodayear           if (sodabnum==1 | sodabnum==5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg    using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg) replace
		xi: xtreg   v72HH rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price  feature display   i.sodayear           if (sodabnum==1 | sodabnum==5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price  feature display   using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price  feature display )
		xi: xtreg   v72HH rtg_ad                  rtg i.superweek   i.sodayear           if (sodabnum~=1 & sodabnum~=5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad                  rtg    using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Not Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad                  rtg) 
		xi: xtreg   v72HH rtg_ad                  rtg  PostGRPs NFLgrps price priceother feature display   i.sodayear           if (sodabnum~=1 & sodabnum~=5) & superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad                  rtg  PostGRPs NFLgrps price priceother feature display   using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Not Coke-Pepsi ) label  nocon  dec(3) 2aster keep(rtg_ad                  rtg  PostGRPs NFLgrps price priceother feature display)
		xi: xtreg   v72HH rtg_ad rtg_ad_both rtg i.superweek                                           i.sodayear           if  superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg                                            using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg )
		xi: xtreg   v72HH rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price priceother feature display   i.sodayear           if  superweek>0, fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price priceother feature display   using Post`top56'SodaVolRegs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(All Brands ) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg  PostGRPs NFLgrps price priceother feature display)


restore


preserve
drop if superweek>20
drop if superweek<1
		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg                                                        i.superweek i.sodayear  if (sodabnum==1 | sodabnum==5) , fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg                                                        using NCAA`top56'Regs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display)
		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg PostGRPs NFLgrps price  feature display  i.sodayear  i.superweek if (sodabnum==1 | sodabnum==5) , fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg PostGRPs NFLgrps price  feature display  using NCAA`top56'Regs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display)
    xi: xtreg   RevHH rtg_ad rtg_ad_both rtg NCAA* rtgNCAA i.sodayear                              i.superweek if (sodabnum==1 | sodabnum==5) , fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg NCAA* rtgNCAA                                          using NCAA`top56'Regs`window'.tex,  ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display)
		xi: xtreg   RevHH rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display  i.superweek i.sodayear  if (sodabnum==1 | sodabnum==5) , fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display  using NCAA`top56'Regs`window'.tex,  ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display)


		xi: xtreg   v72 rtg_ad rtg_ad_both rtg                                                       i.superweek   i.sodayear  if (sodabnum==1 | sodabnum==5) , fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg                                                         using NCAAvol`top56'Regs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display)
		xi: xtreg   v72 rtg_ad rtg_ad_both rtg PostGRPs NFLgrps price  feature display                 i.sodayear  i.superweek if (sodabnum==1 | sodabnum==5) , fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg PostGRPs NFLgrps price  feature display                 using NCAAvol`top56'Regs`window'.tex, tex ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display)
    xi: xtreg   v72 rtg_ad rtg_ad_both rtg NCAArtg NCAArtg_ad NCAArtg_ad_both NCAAPepsi rtgNCAA i.sodayear                                i.superweek if (sodabnum==1 | sodabnum==5) , fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg NCAArtg NCAArtg_ad NCAArtg_ad_both NCAAPepsi rtgNCAA                                         using NCAAvol`top56'Regs`window'.tex,  ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display)
		xi: xtreg   v72 rtg_ad rtg_ad_both rtg NCAArtg NCAArtg_ad NCAArtg_ad_both NCAAPepsi rtgNCAA PostGRPs NFLgrps price  feature display  i.superweek i.sodayear  if (sodabnum==1 | sodabnum==5) , fe i(branddma) cluster(dma)
       outreg2        rtg_ad rtg_ad_both rtg NCAArtg NCAArtg_ad NCAArtg_ad_both NCAAPepsi rtgNCAA PostGRPs NFLgrps price  feature display  using NCAAvol`top56'Regs`window'.tex,  ti(Summary Regressions of Superbowl Ratings) ctitle(Coke-Pepsi) label  nocon  dec(3) 2aster keep(rtg_ad rtg_ad_both rtg NCAA* rtgNCAA PostGRPs NFLgrps price  feature display)

restore
